@@ -60,7 +60,7 @@ class RecordLoader:
         downloadOptions = downloadOptions if downloadOptions is not None else {}
         combineChannels = combineChannels if combineChannels is not None else []
         optionalSignals = optionalSignals if optionalSignals is not None else []
-        optionalSignals = targetSignalTypes if targetSignalTypes is not None else []
+        targetSignalTypes = targetSignalTypes if targetSignalTypes is not None else []
         targetSignals = targetSignals if targetSignals is not None else []
         
         self.filePath = filePath
